@@ -1,30 +1,14 @@
-/* Copyright (C) 2019-2022 Greenbone AG
+/* SPDX-FileCopyrightText: 2024 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Affero General Public License
- * as published by the Free Software Foundation, either version 3
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
-import logger from 'gmp/log';
 
 import registerCommand from 'gmp/command';
-
-import {NO_VALUE} from 'gmp/parser';
-
+import EntitiesCommand from 'gmp/commands/entities';
+import EntityCommand from 'gmp/commands/entity';
+import logger from 'gmp/log';
 import Audit, {HOSTS_ORDERING_SEQUENTIAL} from 'gmp/models/audit';
-
-import EntitiesCommand from './entities';
-import EntityCommand from './entity';
+import {NO_VALUE} from 'gmp/parser';
 
 const log = logger.getLogger('gmp.commands.audits');
 
@@ -36,7 +20,7 @@ export class AuditCommand extends EntityCommand {
   start({id}) {
     log.debug('Starting audit...');
 
-    return this.httpPost({
+    return this.httpPostWithTransform({
       cmd: 'start_task',
       id,
     })
@@ -53,7 +37,7 @@ export class AuditCommand extends EntityCommand {
   stop({id}) {
     log.debug('Stopping audit');
 
-    return this.httpPost({
+    return this.httpPostWithTransform({
       cmd: 'stop_task',
       id,
     })
@@ -68,7 +52,7 @@ export class AuditCommand extends EntityCommand {
   }
 
   resume({id}) {
-    return this.httpPost({
+    return this.httpPostWithTransform({
       cmd: 'resume_task',
       id,
     })
@@ -199,7 +183,7 @@ export class AuditsCommand extends EntitiesCommand {
 
   get(params, options) {
     params = {...params, usage_type: 'audit'};
-    return this.httpGet(params, options).then(response => {
+    return this.httpGetWithTransform(params, options).then(response => {
       const {entities, filter, counts} = this.getCollectionListFromRoot(
         response.data,
       );
@@ -210,5 +194,3 @@ export class AuditsCommand extends EntitiesCommand {
 
 registerCommand('audit', AuditCommand);
 registerCommand('audits', AuditsCommand);
-
-// vim: set ts=2 sw=2 tw=80:
