@@ -1,33 +1,17 @@
-/* Copyright (C) 2016-2022 Greenbone AG
+/* SPDX-FileCopyrightText: 2024 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Affero General Public License
- * as published by the Free Software Foundation, either version 3
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
-import logger from 'gmp/log';
 
-import {isDefined} from 'gmp/utils/identity';
-
-import CollectionCounts from 'gmp/collection/collectioncounts';
+import CollectionCounts from 'gmp/collection/collection-counts';
 import {parseCollectionList} from 'gmp/collection/parser';
-
 import registerCommand from 'gmp/command';
-
+import EntitiesCommand from 'gmp/commands/entities';
+import EntityCommand from 'gmp/commands/entity';
+import logger from 'gmp/log';
 import Filter from 'gmp/models/filter';
-
-import EntitiesCommand from './entities';
-import EntityCommand from './entity';
+import {apiType} from 'gmp/utils/entity-type';
+import {isDefined} from 'gmp/utils/identity';
 
 const log = logger.getLogger('gmp.commands.filters');
 
@@ -42,7 +26,7 @@ class FilterCommand extends EntityCommand {
       cmd: 'create_filter',
       term,
       name,
-      resource_type: type,
+      resource_type: apiType(type),
       comment,
     };
     log.debug('Creating new filter', args, data);
@@ -56,7 +40,7 @@ class FilterCommand extends EntityCommand {
       comment,
       id,
       name,
-      resource_type: type,
+      resource_type: apiType(type),
       term,
     };
     log.debug('Saving filter', args, data);
@@ -84,7 +68,7 @@ const parse_counts = element => {
     isDefined(element.filters) &&
     isDefined(element.filter_count)
   ) {
-    const es = element.filters[1]; // eslint-disable-line prefer-destructuring
+    const es = element.filters[1];
     const ec = element.filter_count;
     return {
       first: es._start,
@@ -114,8 +98,8 @@ class FiltersCommand extends EntitiesCommand {
     const response = this.getEntitiesResponse(root);
     return parseCollectionList(response, this.name, this.clazz, {
       meta,
-      filter_parse_func: parseFilter,
-      collection_count_parse_func: parse_collection_counts,
+      filterParseFunc: parseFilter,
+      collectionCountParseFunc: parse_collection_counts,
     });
   }
 }
@@ -124,5 +108,3 @@ export default FiltersCommand;
 
 registerCommand('filter', FilterCommand);
 registerCommand('filters', FiltersCommand);
-
-// vim: set ts=2 sw=2 tw=80:
