@@ -3,11 +3,11 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import EntityModel, {parseEntityModelProperties} from 'gmp/models/entitymodel';
+import EntityModel, {parseEntityModelProperties} from 'gmp/models/entity-model';
 import convert from 'gmp/models/filter/convert';
 import FilterTerm, {AND} from 'gmp/models/filter/filterterm';
 import {EXTRA_KEYWORDS} from 'gmp/models/filter/keywords';
-import Model, {ModelElement, ModelProperties} from 'gmp/models/model';
+import Model, {type ModelElement, type ModelProperties} from 'gmp/models/model';
 import {parseInt} from 'gmp/parser';
 import {map} from 'gmp/utils/array';
 import {isDefined, isString, isArray, hasValue} from 'gmp/utils/identity';
@@ -95,7 +95,7 @@ const parseFilterTermsFromString = (
  * Represents a filter
  */
 class Filter extends EntityModel {
-  static readonly entityType: string = 'filter';
+  static readonly entityType = 'filter';
 
   readonly alerts: Model[];
   readonly filter_type?: string;
@@ -193,7 +193,7 @@ class Filter extends EntityModel {
    *
    * @return This filter
    */
-  _setTerm(term: FilterTerm) {
+  private _setTerm(term: FilterTerm) {
     const key = term.keyword;
 
     // special handling of sort. should be put into a more generic solution in
@@ -227,7 +227,7 @@ class Filter extends EntityModel {
    *
    * @return This filter
    */
-  _addTerm(...terms: FilterTerm[]) {
+  private _addTerm(...terms: FilterTerm[]) {
     this.terms.push(...terms);
     return this;
   }
@@ -239,7 +239,7 @@ class Filter extends EntityModel {
    *
    * @returns Index of the key in the FilterTerms array
    */
-  _getIndex(key: string): number {
+  private _getIndex(key: string): number {
     return this.terms.findIndex(term => term.keyword === key);
   }
 
@@ -255,7 +255,7 @@ class Filter extends EntityModel {
    * @return This filter with merged terms.
    */
 
-  _mergeExtraKeywords(filter: Filter | undefined | null) {
+  private _mergeExtraKeywords(filter: Filter | undefined | null) {
     if (hasValue(filter)) {
       filter.forEach(term => {
         const {keyword: key} = term;
@@ -283,7 +283,7 @@ class Filter extends EntityModel {
    *
    * @return This filter with merged terms.
    */
-  _mergeNewKeywords(filter: Filter | undefined) {
+  private _mergeNewKeywords(filter: Filter | undefined) {
     if (hasValue(filter)) {
       filter.forEach(term => {
         const {keyword: key} = term;
@@ -304,7 +304,7 @@ class Filter extends EntityModel {
    *
    * @return This filter.
    */
-  _resetFilterId() {
+  private _resetFilterId() {
     // @ts-expect-error
     this.id = undefined;
     return this;
@@ -820,7 +820,13 @@ class Filter extends EntityModel {
 }
 
 export const ALL_FILTER = new Filter().all();
+export const AGENTS_FILTER_FILTER = Filter.fromString('type=agent');
+export const AGENT_GROUPS_FILTER_FILTER = Filter.fromString('type=agent_group');
+export const AGENT_INSTALLERS_FILTER_FILTER = Filter.fromString(
+  'type=agent_installer',
+);
 export const ALERTS_FILTER_FILTER = Filter.fromString('type=alert');
+export const AUDITS_FILTER_FILTER = Filter.fromString('type=task');
 export const AUDIT_REPORTS_FILTER_FILTER =
   Filter.fromString('type=audit_report');
 export const CERTBUND_FILTER_FILTER = Filter.fromString('type=info');
@@ -836,6 +842,7 @@ export const NVTS_FILTER_FILTER = Filter.fromString('type=info');
 export const OS_FILTER_FILTER = Filter.fromString('type=os');
 export const OVERRIDES_FILTER_FILTER = Filter.fromString('type=override');
 export const PORTLISTS_FILTER_FILTER = Filter.fromString('type=port_list');
+export const POLICIES_FILTER_FILTER = Filter.fromString('type=config');
 export const PERMISSIONS_FILTER_FILTER = Filter.fromString('type=permission');
 export const REPORT_CONFIGS_FILTER_FILTER =
   Filter.fromString('type=report_config');
