@@ -3,8 +3,8 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import React, {ReactNode, MouseEvent} from 'react';
-import {Button as OpenSightButton} from '@greenbone/opensight-ui-components-mantinev7';
+import React, {type ReactNode, type MouseEvent} from 'react';
+import {Button as OpenSightButton} from '@greenbone/ui-lib';
 import useValueChange from 'web/components/form/useValueChange';
 
 interface ButtonProps {
