@@ -4,8 +4,8 @@
  */
 
 import React, {useCallback} from 'react';
-import {CheckboxProps as MantineCheckboxProps} from '@mantine/core';
-import {Checkbox as OpenSightCheckbox} from '@greenbone/opensight-ui-components-mantinev7';
+import {type CheckboxProps as MantineCheckboxProps} from '@mantine/core';
+import {Checkbox as OpenSightCheckbox} from '@greenbone/ui-lib';
 
 type ChangeEvent = React.ChangeEvent<HTMLInputElement>;
 
