@@ -4,9 +4,9 @@
  */
 
 import {useCallback} from 'react';
-import {DatePickerInput} from '@greenbone/opensight-ui-components-mantinev7';
-import {DateValue} from '@mantine/dates';
-import date, {Date} from 'gmp/models/date';
+import {DatePickerInput} from '@greenbone/ui-lib';
+import {type DateValue} from '@mantine/dates';
+import date, {type Date} from 'gmp/models/date';
 import {isDefined} from 'gmp/utils/identity';
 import useLanguage from 'web/hooks/useLanguage';
 
