@@ -4,8 +4,10 @@
  */
 
 import React from 'react';
-import useClickHandler, {ClickEvent} from 'web/components/form/useClickHandler';
-import {updateDisplayName} from 'web/utils/displayName';
+import useClickHandler, {
+  type ClickEvent,
+} from 'web/components/form/useClickHandler';
+import {updateDisplayName} from 'web/utils/display-name';
 
 type WrappedComponent<TEvent> = React.ComponentType<{
   onClick?: (event: TEvent) => void;
