@@ -5,8 +5,8 @@
 
 import React from 'react';
 import Download from 'web/components/form/Download';
-import useDownload, {DownloadFunc} from 'web/components/form/useDownload';
-import {updateDisplayName} from 'web/utils/displayName';
+import useDownload, {type DownloadFunc} from 'web/components/form/useDownload';
+import {updateDisplayName} from 'web/utils/display-name';
 
 interface DownloadProps {
   onDownload: DownloadFunc;
