@@ -6,19 +6,19 @@
 import {useEffect} from 'react';
 import {isDefined} from 'gmp/utils/identity';
 import useGmp from 'web/hooks/useGmp';
-import {applianceTitle} from 'web/utils/applianceData';
+import {applianceTitle} from 'web/utils/appliance-data';
 
 interface PageTitleProps {
   title?: string;
 }
 
-export const DEFAULT_TITLE = 'Greenbone Security Assistant';
-
 const PageTitle = ({title: pageTitle}: PageTitleProps) => {
   const gmp = useGmp();
-  const vendorLabel = gmp?.settings?.vendorLabel || 'defaultVendorLabel';
+  const vendorLabel = gmp?.settings?.vendorLabel ?? 'defaultVendorLabel';
+
   const vendorTitle = gmp?.settings?.vendorTitle;
-  const title = vendorTitle ?? applianceTitle[vendorLabel] ?? DEFAULT_TITLE;
+
+  const title = vendorTitle ?? applianceTitle[vendorLabel];
 
   useEffect(() => {
     if (isDefined(pageTitle)) {
