@@ -3,13 +3,14 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
+import {type EntityType} from 'gmp/utils/entity-type';
 import {isDefined} from 'gmp/utils/identity';
-import Link, {LinkProps} from 'web/components/link/Link';
+import Link, {type LinkProps} from 'web/components/link/Link';
 import useCapabilities from 'web/hooks/useCapabilities';
 
 export interface DetailsLinkProps extends LinkProps {
   id: string;
-  type: string;
+  type: EntityType;
   textOnly?: boolean;
 }
 
