@@ -3,27 +3,30 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {AppNavigation} from '@greenbone/opensight-ui-components-mantinev7';
+import {AppNavigation} from '@greenbone/ui-lib';
 import {
   BarChart3,
+  CircleHelp,
+  FileCheck,
   Server,
   ShieldCheck,
+  SlidersHorizontal,
   View,
   Wrench,
-  SlidersHorizontal,
-  FileCheck,
-  CircleHelp,
 } from 'lucide-react';
 import {useLocation, useMatch} from 'react-router';
+import {type EntityType} from 'gmp/utils/entity-type';
 import {isDefined} from 'gmp/utils/identity';
 import Link from 'web/components/link/Link';
 import useCapabilities from 'web/hooks/useCapabilities';
+import useFeatures from 'web/hooks/useFeatures';
 import useGmp from 'web/hooks/useGmp';
 import useTranslation from 'web/hooks/useTranslation';
 
 const Menu = () => {
   const [_] = useTranslation();
   const capabilities = useCapabilities();
+  const features = useFeatures();
   const gmp = useGmp();
   const tasksMatch = useMatch('/tasks');
   const taskMatch = useMatch('/task/*');
@@ -124,6 +127,26 @@ const Menu = () => {
   const alertMatch = useMatch('/alert/*');
   const isAlertsActive = Boolean(alertsMatch || alertMatch);
 
+  const agentsMatch = useMatch('/agents');
+  const agentMatch = useMatch('/agent/*');
+  const isAgentsActive = Boolean(agentsMatch || agentMatch);
+
+  const agentGroupsMatch = useMatch('/agent-groups');
+  const agentGroupMatch = useMatch('/agent-group/*');
+  const isAgentGroupsActive = Boolean(agentGroupsMatch || agentGroupMatch);
+
+  const agentInstallersMatch = useMatch('/agent-installers');
+  const agentInstallerMatch = useMatch('/agent-installer/*');
+  const isAgentInstallersActive = Boolean(
+    agentInstallersMatch || agentInstallerMatch,
+  );
+
+  const containerImageTargetsMatch = useMatch('/ociimagetargets');
+  const containerImageTargetMatch = useMatch('/ociimagetarget/*');
+  const isContainerImageTargetsActive = Boolean(
+    containerImageTargetsMatch || containerImageTargetMatch,
+  );
+
   const schedulesMatch = useMatch('/schedules');
   const scheduleMatch = useMatch('/schedule/*');
   const isSchedulesActive = Boolean(schedulesMatch || scheduleMatch);
@@ -172,41 +195,45 @@ const Menu = () => {
   const isTrashcanActive = Boolean(useMatch('/trashcan'));
   const isFeedStatusActive = Boolean(useMatch('/feedstatus'));
   const isLdapActive = Boolean(useMatch('/ldap'));
+  const isCredentialStoreActive = Boolean(useMatch('/credentialstore'));
   const isRadiusActive = Boolean(useMatch('/radius'));
   const isCvssCalculatorActive = Boolean(useMatch('/cvsscalculator'));
-  const isAboutActive = Boolean(useMatch('/about'));
 
-  const mayAccessAny = (keys: string[]) =>
+  const mayAccessAny = (keys: EntityType[]) =>
     keys.some(key => isDefined(capabilities) && capabilities.mayAccess(key));
 
   const mayOpScans = mayAccessAny([
-    'tasks',
-    'reports',
-    'results',
-    'vulns',
-    'overrides',
-    'notes',
+    'task',
+    'report',
+    'result',
+    'vulnerability',
+    'override',
+    'note',
   ]);
   const mayOpConfiguration = mayAccessAny([
-    'targets',
-    'portlists',
-    'credentials',
-    'scanconfigs',
-    'alerts',
-    'schedules',
-    'reportconfigs',
-    'reportformats',
-    'scanners',
-    'filters',
-    'tags',
+    'agent',
+    'agentgroup',
+    'agentinstaller',
+    'target',
+    'ociimagetarget',
+    'portlist',
+    'credential',
+    'scanconfig',
+    'alert',
+    'schedule',
+    'reportconfig',
+    'reportformat',
+    'scanner',
+    'filter',
+    'tag',
   ]);
   const mayOpResilience = mayAccessAny([
-    'tickets',
-    'policies',
-    'audits',
-    'auditreports',
+    'ticket',
+    'policy',
+    'audit',
+    'auditreport',
   ]);
-  const mayOpAssets = mayAccessAny(['assets', 'tls_certificates']);
+  const mayOpAssets = mayAccessAny(['asset', 'tlscertificate']);
 
   const menuPoints = [
     [
@@ -231,40 +258,40 @@ const Menu = () => {
           isOverridesActive,
         ].some(Boolean),
         subNav: [
-          capabilities?.mayAccess('tasks') && {
+          capabilities.mayAccess('task') && {
             label: _('Tasks'),
             to: '/tasks',
-            isPathMatch: isTasksActive,
+            isPathMatch: Boolean(tasksMatch),
             active: isTasksActive,
           },
-          capabilities?.mayAccess('reports') && {
+          capabilities.mayAccess('report') && {
             label: _('Reports'),
             to: '/reports',
-            isPathMatch: isReportsActive,
+            isPathMatch: Boolean(reportsMatch),
             active: isReportsActive,
           },
-          capabilities?.mayAccess('results') && {
+          capabilities.mayAccess('result') && {
             label: _('Results'),
             to: '/results',
-            isPathMatch: isResultsActive,
+            isPathMatch: Boolean(resultsMatch),
             active: isResultsActive,
           },
-          capabilities?.mayAccess('vulns') && {
+          capabilities.mayAccess('vulnerability') && {
             label: _('Vulnerabilities'),
             to: '/vulnerabilities',
-            isPathMatch: isVulnerabilitiesActive,
+            isPathMatch: Boolean(vulnerabilitiesMatch),
             active: isVulnerabilitiesActive,
           },
-          capabilities?.mayAccess('notes') && {
+          capabilities.mayAccess('note') && {
             label: _('Notes'),
             to: '/notes',
-            isPathMatch: isNotesActive,
+            isPathMatch: Boolean(notesMatch),
             active: isNotesActive,
           },
-          capabilities?.mayAccess('overrides') && {
+          capabilities.mayAccess('override') && {
             label: _('Overrides'),
             to: '/overrides',
-            isPathMatch: isOverridesActive,
+            isPathMatch: Boolean(overridesMatch),
             active: isOverridesActive,
           },
         ].filter(Boolean),
@@ -279,22 +306,22 @@ const Menu = () => {
           isTlsCertificatesActive,
         ].some(Boolean),
         subNav: [
-          capabilities?.mayAccess('assets') && {
+          capabilities.mayAccess('host') && {
             label: _('Hosts'),
             to: '/hosts',
-            isPathMatch: isHostsActive,
+            isPathMatch: Boolean(hostsMatch),
             active: isHostsActive,
           },
-          capabilities?.mayAccess('assets') && {
+          capabilities.mayAccess('operatingsystem') && {
             label: _('Operating Systems'),
             to: '/operatingsystems',
-            isPathMatch: isOperatingSystemsActive,
+            isPathMatch: Boolean(operatingSystemsMatch),
             active: isOperatingSystemsActive,
           },
-          capabilities?.mayAccess('tlscertificates') && {
+          capabilities.mayAccess('tlscertificate') && {
             label: _('TLS Certificates'),
             to: '/tlscertificates',
-            isPathMatch: isTlsCertificatesActive,
+            isPathMatch: Boolean(tlsCertificatesMatch),
             active: isTlsCertificatesActive,
           },
         ].filter(Boolean),
@@ -310,33 +337,33 @@ const Menu = () => {
           isAuditReportsActive,
         ].some(Boolean),
         subNav: [
-          capabilities?.mayAccess('tickets') && {
+          capabilities.mayAccess('ticket') && {
             label: _('Remediation Tickets'),
             to: '/tickets',
-            isPathMatch: isTicketsActive,
+            isPathMatch: Boolean(ticketsMatch),
             active: isTicketsActive,
           },
-          capabilities?.mayAccess('policies') && {
+          capabilities.mayAccess('policy') && {
             label: _('Compliance Policies'),
             to: '/policies',
-            isPathMatch: isPoliciesActive,
+            isPathMatch: Boolean(policiesMatch),
             active: isPoliciesActive,
           },
-          capabilities?.mayAccess('audits') && {
+          capabilities.mayAccess('audit') && {
             label: _('Compliance Audits'),
             to: '/audits',
-            isPathMatch: isAuditsActive,
+            isPathMatch: Boolean(auditsMatch),
             active: isAuditsActive,
           },
-          capabilities?.mayAccess('auditreports') && {
+          capabilities.mayAccess('auditreport') && {
             label: _('Compliance Audit Reports'),
             to: '/auditreports',
-            isPathMatch: isAuditReportsActive,
+            isPathMatch: Boolean(auditReportsMatch),
             active: isAuditReportsActive,
           },
         ].filter(Boolean),
       },
-      capabilities?.mayAccess('info') && {
+      capabilities.mayAccess('info') && {
         icon: View,
         label: _('Security Information'),
         key: 'secInfo',
@@ -351,31 +378,31 @@ const Menu = () => {
           {
             label: _('NVTs'),
             to: '/nvts',
-            isPathMatch: isNvtsActive,
+            isPathMatch: Boolean(nvtsMatch),
             active: isNvtsActive,
           },
           {
             label: _('CVEs'),
             to: '/cves',
-            isPathMatch: isCvesActive,
+            isPathMatch: Boolean(cvesMatch),
             active: isCvesActive,
           },
           {
             label: _('CPEs'),
             to: '/cpes',
-            isPathMatch: isCpesActive,
+            isPathMatch: Boolean(cpesMatch),
             active: isCpesActive,
           },
           {
             label: _('CERT-Bund Advisories'),
             to: '/certbunds',
-            isPathMatch: isCertbundsActive,
+            isPathMatch: Boolean(certbundsMatch),
             active: isCertbundsActive,
           },
           {
             label: _('DFN-CERT Advisories'),
             to: '/dfncerts',
-            isPathMatch: isDfncertsActive,
+            isPathMatch: Boolean(dfncertsMatch),
             active: isDfncertsActive,
           },
         ],
@@ -386,6 +413,7 @@ const Menu = () => {
         key: 'configuration',
         defaultOpened: [
           isTargetsActive,
+          isContainerImageTargetsActive,
           isPortlistsActive,
           isCredentialsActive,
           isScanConfigsActive,
@@ -396,74 +424,105 @@ const Menu = () => {
           isScannersActive,
           isFiltersActive,
           isTagsActive,
+          isAgentsActive,
+          isAgentGroupsActive,
+          isAgentInstallersActive,
         ].some(Boolean),
         subNav: [
-          capabilities?.mayAccess('targets') && {
+          capabilities.mayAccess('target') && {
             label: _('Targets'),
             to: '/targets',
-            isPathMatch: isTargetsActive,
+            isPathMatch: Boolean(targetsMatch),
             active: isTargetsActive,
           },
-          capabilities?.mayAccess('portlists') && {
+          capabilities.mayAccess('ociimagetarget') &&
+            features.featureEnabled('ENABLE_CONTAINER_SCANNING') && {
+              label: _('Container Image Targets'),
+              to: '/ociimagetargets',
+              isPathMatch: Boolean(containerImageTargetsMatch),
+              active: isContainerImageTargetsActive,
+            },
+          capabilities.mayAccess('portlist') && {
             label: _('Port Lists'),
             to: '/portlists',
-            isPathMatch: isPortlistsActive,
+            isPathMatch: Boolean(portlistsMatch),
             active: isPortlistsActive,
           },
-          capabilities?.mayAccess('credentials') && {
+          capabilities.mayAccess('credential') && {
             label: _('Credentials'),
             to: '/credentials',
-            isPathMatch: isCredentialsActive,
+            isPathMatch: Boolean(credentialsMatch),
             active: isCredentialsActive,
           },
-          capabilities?.mayAccess('scanconfigs') && {
+          capabilities.mayAccess('scanconfig') && {
             label: _('Scan Configs'),
             to: '/scanconfigs',
-            isPathMatch: isScanConfigsActive,
+            isPathMatch: Boolean(scanConfigsMatch),
             active: isScanConfigsActive,
           },
-          capabilities?.mayAccess('alerts') && {
+          capabilities.mayAccess('alert') && {
             label: _('Alerts'),
             to: '/alerts',
-            isPathMatch: isAlertsActive,
+            isPathMatch: Boolean(alertsMatch),
             active: isAlertsActive,
           },
-          capabilities?.mayAccess('schedules') && {
+          capabilities.mayAccess('schedule') && {
             label: _('Schedules'),
             to: '/schedules',
-            isPathMatch: isSchedulesActive,
+            isPathMatch: Boolean(schedulesMatch),
             active: isSchedulesActive,
           },
-          capabilities?.mayAccess('reportconfigs') && {
+          capabilities.mayAccess('reportconfig') && {
             label: _('Report Configs'),
             to: '/reportconfigs',
-            isPathMatch: isReportConfigsActive,
+            isPathMatch: Boolean(reportConfigsMatch),
             active: isReportConfigsActive,
           },
-          capabilities?.mayAccess('reportformats') && {
+          capabilities.mayAccess('reportformat') && {
             label: _('Report Formats'),
             to: '/reportformats',
-            isPathMatch: isReportFormatsActive,
+            isPathMatch: Boolean(reportFormatsMatch),
             active: isReportFormatsActive,
           },
-          capabilities?.mayAccess('scanners') && {
+          capabilities.mayAccess('scanner') && {
             label: _('Scanners'),
             to: '/scanners',
-            isPathMatch: isScannersActive,
+            isPathMatch: Boolean(scannersMatch),
             active: isScannersActive,
           },
-          capabilities?.mayAccess('filters') && {
+          capabilities.mayAccess('filter') && {
             label: _('Filters'),
             to: '/filters',
-            isPathMatch: isFiltersActive,
+            isPathMatch: Boolean(filtersMatch),
             active: isFiltersActive,
           },
-          capabilities?.mayAccess('tags') && {
+          capabilities.mayAccess('tag') && {
             label: _('Tags'),
             to: '/tags',
-            isPathMatch: isTagsActive,
+            isPathMatch: Boolean(tagsMatch),
             active: isTagsActive,
           },
+          capabilities.mayAccess('agent') &&
+            features.featureEnabled('ENABLE_AGENTS') && {
+              label: _('Agents'),
+              to: '/agents',
+              isPathMatch: Boolean(agentsMatch),
+              active: isAgentsActive,
+            },
+          capabilities.mayAccess('agentgroup') &&
+            features.featureEnabled('ENABLE_AGENTS') && {
+              label: _('Agent Groups'),
+              to: '/agent-groups',
+              isPathMatch: Boolean(agentGroupsMatch),
+              active: isAgentGroupsActive,
+            },
+          capabilities.mayAccess('agentinstaller') &&
+            features.featureEnabled('ENABLE_AGENTS') && {
+              label: _('Agent Installers'),
+              to: '/agent-installers',
+              isPathMatch: Boolean(agentInstallersMatch),
+              active: isAgentInstallersActive,
+            },
         ].filter(Boolean),
       },
       {
@@ -479,34 +538,35 @@ const Menu = () => {
           isTrashcanActive,
           isFeedStatusActive,
           isLdapActive,
+          isCredentialStoreActive,
           isRadiusActive,
         ].some(Boolean),
         subNav: [
-          capabilities?.mayAccess('users') && {
+          capabilities.mayAccess('user') && {
             label: _('Users'),
             to: '/users',
-            isPathMatch: isUserActive,
+            isPathMatch: Boolean(usersMatch),
             active: isUserActive,
           },
-          capabilities?.mayAccess('groups') && {
+          capabilities.mayAccess('group') && {
             label: _('Groups'),
             to: '/groups',
-            isPathMatch: isGroupsActive,
+            isPathMatch: Boolean(groupsMatch),
             active: isGroupsActive,
           },
-          capabilities?.mayAccess('roles') && {
+          capabilities.mayAccess('role') && {
             label: _('Roles'),
             to: '/roles',
-            isPathMatch: isRolesActive,
+            isPathMatch: Boolean(rolesMatch),
             active: isRolesActive,
           },
-          capabilities?.mayAccess('permissions') && {
+          capabilities.mayAccess('permission') && {
             label: _('Permissions'),
             to: '/permissions',
-            isPathMatch: isPermissionsActive,
+            isPathMatch: Boolean(permissionsMatch),
             active: isPermissionsActive,
           },
-          capabilities?.mayAccess('system_reports') && {
+          capabilities.mayOp('get_system_reports') && {
             label: _('Performance'),
             to: '/performance',
             isPathMatch: isPerformanceActive,
@@ -518,21 +578,29 @@ const Menu = () => {
             isPathMatch: isTrashcanActive,
             active: isTrashcanActive,
           },
-          capabilities?.mayAccess('feeds') && {
+          capabilities.mayOp('get_feeds') && {
             label: _('Feed Status'),
             to: '/feedstatus',
             isPathMatch: isFeedStatusActive,
             active: isFeedStatusActive,
           },
-          capabilities?.mayOp('describe_auth') &&
-            capabilities?.mayOp('modify_auth') && {
+          capabilities.mayOp('describe_auth') &&
+            capabilities.mayOp('modify_auth') && {
               label: _('LDAP'),
               to: '/ldap',
               isPathMatch: isLdapActive,
               active: isLdapActive,
             },
-          capabilities?.mayOp('describe_auth') &&
-            capabilities?.mayOp('modify_auth') && {
+          capabilities.mayOp('describe_auth') &&
+            features.featureEnabled('ENABLE_CREDENTIAL_STORES') &&
+            capabilities.mayOp('modify_auth') && {
+              label: _('Credential Store'),
+              to: '/credentialstore',
+              isPathMatch: isCredentialStoreActive,
+              active: isCredentialStoreActive,
+            },
+          capabilities.mayOp('describe_auth') &&
+            capabilities.mayOp('modify_auth') && {
               label: _('RADIUS'),
               to: '/radius',
               isPathMatch: isRadiusActive,
@@ -544,7 +612,7 @@ const Menu = () => {
         label: _('Help'),
         key: 'help',
         icon: CircleHelp,
-        defaultOpened: [isCvssCalculatorActive, isAboutActive].some(Boolean),
+        defaultOpened: [isCvssCalculatorActive].some(Boolean),
         subNav: [
           {
             label: _('CVSS Calculator'),
@@ -552,12 +620,6 @@ const Menu = () => {
             isPathMatch: isCvssCalculatorActive,
             active: isCvssCalculatorActive,
           },
-          {
-            label: _('About'),
-            to: '/about',
-            isPathMatch: isAboutActive,
-            active: isAboutActive,
-          },
         ],
       },
     ].filter(Boolean),
