@@ -8,10 +8,17 @@ import Table from 'web/components/table/Table';
 interface SimpleTableProps {
   size?: string;
   children?: React.ReactNode;
+  'data-testid'?: string;
 }
 
-const SimpleTable = ({size = 'auto', children}: SimpleTableProps) => (
-  <Table $size={size}>{children}</Table>
+const SimpleTable = ({
+  size = 'auto',
+  children,
+  'data-testid': dataTestId,
+}: SimpleTableProps) => (
+  <Table $size={size} data-testid={dataTestId}>
+    {children}
+  </Table>
 );
 
 export default SimpleTable;
