@@ -4,20 +4,20 @@
  */
 
 import React from 'react';
-import {showSuccessNotification} from '@greenbone/opensight-ui-components-mantinev7';
+import {showSuccessNotification} from '@greenbone/ui-lib';
 import {connect} from 'react-redux';
-import {Location} from 'react-router';
-import CollectionCounts from 'gmp/collection/CollectionCounts';
-import EntitiesCommand from 'gmp/commands/entities';
-import Gmp from 'gmp/gmp';
-import Rejection from 'gmp/http/rejection';
-import Response from 'gmp/http/response';
-import {XmlMeta, XmlResponseData} from 'gmp/http/transform/fastxml';
-import {TranslateOptions} from 'gmp/locale/lang';
+import {type Location} from 'react-router';
+import type CollectionCounts from 'gmp/collection/collection-counts';
+import type EntitiesCommand from 'gmp/commands/entities';
+import type Gmp from 'gmp/gmp';
+import type Rejection from 'gmp/http/rejection';
+import type Response from 'gmp/http/response';
+import {type XmlMeta} from 'gmp/http/transform/fast-xml';
+import {type TranslateOptions} from 'gmp/locale/lang';
 import logger from 'gmp/log';
-import Filter, {RESET_FILTER} from 'gmp/models/filter';
-import Model from 'gmp/models/model';
-import Tag from 'gmp/models/tag';
+import {type default as Filter, RESET_FILTER} from 'gmp/models/filter';
+import type Model from 'gmp/models/model';
+import type Tag from 'gmp/models/tag';
 import {YES_VALUE} from 'gmp/parser';
 import {map} from 'gmp/utils/array';
 import {
@@ -25,10 +25,16 @@ import {
   apiType,
   typeName,
   pluralizeType,
-} from 'gmp/utils/entitytype';
+  type EntityType,
+} from 'gmp/utils/entity-type';
 import {isDefined} from 'gmp/utils/identity';
-import TagsDialog, {TagsDialogData} from 'web/entities/TagsDialog';
-import actionFunction from 'web/entity/hooks/actionFunction';
+import {
+  type OnFilterChangedFunc,
+  type OnFilterCreatedFunc,
+} from 'web/components/powerfilter/useFilterDialogSave';
+import TagsDialog, {type TagsDialogData} from 'web/entities/TagsDialog';
+import actionFunction from 'web/entity/hooks/action-function';
+import {type OnDownloadedFunc} from 'web/entity/hooks/useEntityDownload';
 import TagDialog from 'web/pages/tags/Dialog';
 import {createDeleteEntity} from 'web/store/entities/utils/actions';
 import {loadUserSettingDefaults} from 'web/store/usersettings/defaults/actions';
@@ -36,15 +42,15 @@ import {getUserSettingsDefaults} from 'web/store/usersettings/defaults/selectors
 import {getUsername} from 'web/store/usersettings/selectors';
 import compose from 'web/utils/Compose';
 import {generateFilename} from 'web/utils/Render';
-import SelectionType, {SelectionTypeType} from 'web/utils/SelectionType';
-import SortDirection, {SortDirectionType} from 'web/utils/SortDirection';
+import SelectionType, {type SelectionTypeType} from 'web/utils/SelectionType';
+import SortDirection, {type SortDirectionType} from 'web/utils/sort-direction';
 import {withRouter} from 'web/utils/withRouter';
 import withTranslation from 'web/utils/withTranslation';
 
 type NavigateFunction = (args: {pathname: string; search?: string}) => void;
 
 export interface EntitiesContainerRenderProps<TModel extends Model = Model> {
-  createFilterType: string;
+  createFilterType: EntityType;
   entities?: TModel[];
   entitiesCounts?: CollectionCounts;
   entitiesError?: Error | Rejection;
@@ -59,12 +65,12 @@ export interface EntitiesContainerRenderProps<TModel extends Model = Model> {
   onDelete: (entity: TModel) => Promise<void>;
   onDeleteBulk: () => Promise<void>;
   onDownloadBulk: () => Promise<void>;
-  onDownloaded: (data: {filename: string; data: string}) => void;
+  onDownloaded: OnDownloadedFunc;
   onEntitySelected: (entity: TModel) => void;
   onEntityDeselected: (entity: TModel) => void;
   onError: (error: Error | Rejection) => void;
-  onFilterChanged: (filter: Filter) => void;
-  onFilterCreated: (filter: Filter) => void;
+  onFilterChanged: OnFilterChangedFunc;
+  onFilterCreated: OnFilterCreatedFunc;
   onFilterRemoved: () => void;
   onFilterReset: () => void;
   onFirstClick: () => void;
@@ -100,7 +106,7 @@ interface EntitiesContainerProps<TModel extends Model = Model> {
   entitiesError?: Error | Rejection;
   filter: Filter;
   gmp: Gmp;
-  gmpName: string;
+  gmpName: EntityType;
   isLoading?: boolean;
   loadedFilter?: Filter;
   notify: (message: string) => () => void;
@@ -109,7 +115,7 @@ interface EntitiesContainerProps<TModel extends Model = Model> {
   showErrorMessage: (message: string) => void;
   showSuccessMessage: (message: string) => void;
   updateFilter: (filter?: Filter) => void;
-  onDownload: (data: {filename: string; data: string}) => void;
+  onDownload: OnDownloadedFunc;
 }
 
 interface EntitiesContainerPropsWithHOCs<TModel extends Model = Model>
@@ -152,6 +158,12 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
 
     this.entitiesCommand = gmp[entitiesCommandName];
 
+    if (!isDefined(this.entitiesCommand)) {
+      throw new Error(
+        `EntitiesContainer: gmp.${entitiesCommandName} is not defined.`,
+      );
+    }
+
     this.notifyTimer = notify(`${entitiesCommandName}.timer`);
     this.notifyChanged = notify(`${entitiesCommandName}.changed`);
 
@@ -270,7 +282,7 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
     const {entities = [], loadedFilter, selected, selectionType} = this.state;
     const {listExportFileName, username, onDownload} = this.props;
 
-    let promise: Promise<Response<XmlResponseData, XmlMeta>>;
+    let promise: Promise<Response<string>>;
 
     if (selectionType === SelectionType.SELECTION_USER) {
       promise = entitiesCommand.export(Array.from(selected as Set<TModel>));
@@ -290,7 +302,6 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
         username,
       });
       const {data} = response;
-      // @ts-expect-error
       onDownload({filename, data});
       showSuccessNotification('', _('Bulk download completed.'));
     } catch (error) {
@@ -567,7 +578,7 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
       showSuccessMessage,
     } = this.props;
 
-    let entitiesType: string | undefined;
+    let entitiesType: EntityType | undefined;
     let resourceTypes: [string, string][] | undefined;
     if (isDefined(entities) && entities.length > 0) {
       entitiesType = getEntityType(entities[0]);
@@ -595,7 +606,7 @@ class EntitiesContainer<TModel extends Model> extends React.Component<
     return (
       <React.Fragment>
         {children({
-          createFilterType: apiType(this.props.gmpName) as string,
+          createFilterType: this.props.gmpName,
           entities,
           entitiesCounts,
           entitiesError,
@@ -671,9 +682,9 @@ const mapStateToProps = rootState => {
 
 const mapDispatchToProps = (
   dispatch,
-  {gmpname, gmp}: {gmpname: string; gmp: Gmp},
+  {gmpName, gmp}: {gmpName: string; gmp: Gmp},
 ) => {
-  const deleteEntity = createDeleteEntity({entityType: gmpname});
+  const deleteEntity = createDeleteEntity({entityType: gmpName});
   return {
     deleteEntity: (id: string) => dispatch(deleteEntity(gmp)(id)),
     loadSettings: () => dispatch(loadUserSettingDefaults(gmp)()),
