@@ -18,44 +18,52 @@ import Credential, {
   CERTIFICATE_CREDENTIAL_TYPE,
   USERNAME_SSH_KEY_CREDENTIAL_TYPE,
   KRB5_CREDENTIAL_TYPE,
+  ESXI_CREDENTIAL_TYPES,
+  SSH_CREDENTIAL_TYPES,
+  SMB_CREDENTIAL_TYPES,
+  SNMP_CREDENTIAL_TYPES,
 } from 'gmp/models/credential';
 import Filter from 'gmp/models/filter';
-import {ALIVE_TESTS} from 'gmp/models/target';
-import {NO_VALUE, YES_VALUE} from 'gmp/parser';
+import {
+  ARP_PING,
+  CONSIDER_ALIVE,
+  ICMP_PING,
+  SCAN_CONFIG_DEFAULT,
+} from 'gmp/models/target';
 import TargetDialog, {
-  ALIVE_TESTS_DEFAULT,
+  DEFAULT_PORT_LIST_ID,
   DEFAULT_PORT_LIST_NAME,
 } from 'web/pages/targets/TargetDialog';
-import {UNSET_LABEL, UNSET_VALUE} from 'web/utils/Render';
+import {UNSET_LABEL} from 'web/utils/Render';
 
 const cred1 = new Credential({
   id: '5678',
   name: 'client certificate',
-  credential_type: CERTIFICATE_CREDENTIAL_TYPE,
+  credentialType: CERTIFICATE_CREDENTIAL_TYPE,
 });
 
 const cred2 = new Credential({
   id: '2345',
   name: 'username+password',
-  credential_type: USERNAME_PASSWORD_CREDENTIAL_TYPE,
+  credentialType: USERNAME_PASSWORD_CREDENTIAL_TYPE,
 });
 
 const cred3 = new Credential({
   id: '5463',
   name: 'up2',
-  credential_type: USERNAME_PASSWORD_CREDENTIAL_TYPE,
+  credentialType: USERNAME_PASSWORD_CREDENTIAL_TYPE,
 });
 
 const cred4 = new Credential({
   id: '6536',
   name: 'ssh_key',
-  credential_type: USERNAME_SSH_KEY_CREDENTIAL_TYPE,
+  credentialType: USERNAME_SSH_KEY_CREDENTIAL_TYPE,
 });
 
 const cred5 = new Credential({
   id: '2345',
   name: 'krb5_key',
-  credential_type: KRB5_CREDENTIAL_TYPE,
+  credentialType: KRB5_CREDENTIAL_TYPE,
 });
 
 const credentials = [cred1, cred2, cred3, cred4, cred5];
@@ -80,16 +88,10 @@ describe('TargetDialog tests', () => {
       <TargetDialog
         credentials={credentials}
         onClose={handleClose}
-        onEsxiCredentialChange={handleChange}
-        onKrb5CredentialChange={handleChange}
         onNewCredentialsClick={handleCreate}
         onNewPortListClick={handleCreate}
         onPortListChange={handleChange}
         onSave={handleSave}
-        onSmbCredentialChange={handleChange}
-        onSnmpCredentialChange={handleChange}
-        onSshCredentialChange={handleChange}
-        onSshElevateCredentialChange={handleChange}
       />,
     );
 
@@ -133,23 +135,27 @@ describe('TargetDialog tests', () => {
     const allowSimultaneousIPsInputs = screen.getAllByName(
       'allowSimultaneousIPs',
     );
-    expect(allowSimultaneousIPsInputs[0]).toHaveAttribute('value', '1');
     expect(allowSimultaneousIPsInputs[0]).toBeChecked();
-    expect(allowSimultaneousIPsInputs[1]).toHaveAttribute('value', '0');
     expect(allowSimultaneousIPsInputs[1]).not.toBeChecked();
 
     expect(screen.getDialogContent()).not.toHaveTextContent(
       'Elevate privileges',
     ); // elevate privileges should not be rendered without valid sshCredentialId
 
-    const selects = screen.queryAllSelectElements();
-    expect(selects.length).toEqual(6); // Should have 6 selects (Kerberos is disabled by default)
-    expect(selects[0]).toHaveValue(DEFAULT_PORT_LIST_NAME); // alive test select
-    expect(selects[1]).toHaveValue(ALIVE_TESTS_DEFAULT); // alive test select
-    expect(selects[2]).toHaveValue(UNSET_LABEL); // ssh credential select
-    expect(selects[3]).toHaveValue(UNSET_LABEL); // elevate privilege select
-    expect(selects[4]).toHaveValue(UNSET_LABEL); // smb credential select
-    expect(selects[5]).toHaveValue(UNSET_LABEL); // esxi credential select
+    expect(screen.getByName('aliveTests')).toHaveValue('');
+
+    const aliveTestsRadios = screen.getAllByName('baseAliveTests');
+    expect(aliveTestsRadios[0]).toHaveAttribute('value', 'Scan Config Default');
+    expect(aliveTestsRadios[0]).toBeChecked();
+    expect(aliveTestsRadios[1]).toHaveAttribute('value', 'Consider Alive');
+    expect(aliveTestsRadios[1]).not.toBeChecked();
+    expect(aliveTestsRadios[2]).toHaveAttribute('value', 'custom');
+    expect(aliveTestsRadios[2]).not.toBeChecked();
+
+    expect(screen.getByName('portListId')).toHaveValue(DEFAULT_PORT_LIST_ID);
+    expect(screen.getByName('sshCredentialId')).toHaveValue(undefined);
+    expect(screen.getByName('smbCredentialId')).toHaveValue(undefined);
+    expect(screen.getByName('esxiCredentialId')).toHaveValue(undefined);
 
     expect(screen.getByTitle('Create a new port list')).toBeInTheDocument();
     const createCredentialIcons = screen.getAllByTitle(
@@ -158,15 +164,11 @@ describe('TargetDialog tests', () => {
     expect(createCredentialIcons.length).toEqual(4); // Each icon has both a span and an svg icon. There should be 4 total (Kerberos is disabled by default)
 
     const reverseLookupOnlyInputs = screen.getAllByName('reverseLookupOnly');
-    expect(reverseLookupOnlyInputs[0]).toHaveAttribute('value', '1');
     expect(reverseLookupOnlyInputs[0]).not.toBeChecked();
-    expect(reverseLookupOnlyInputs[1]).toHaveAttribute('value', '0');
     expect(reverseLookupOnlyInputs[1]).toBeChecked();
 
     const reverseLookupUnifyInputs = screen.getAllByName('reverseLookupUnify');
-    expect(reverseLookupUnifyInputs[0]).toHaveAttribute('value', '1');
     expect(reverseLookupUnifyInputs[0]).not.toBeChecked();
-    expect(reverseLookupUnifyInputs[1]).toHaveAttribute('value', '0');
     expect(reverseLookupUnifyInputs[1]).toBeChecked();
   });
 
@@ -180,28 +182,22 @@ describe('TargetDialog tests', () => {
 
     render(
       <TargetDialog
-        aliveTests={ALIVE_TESTS.SCAN_CONFIG_DEFAULT}
-        allowSimultaneousIPs={NO_VALUE}
+        aliveTests={[SCAN_CONFIG_DEFAULT]}
+        allowSimultaneousIPs={false}
         comment="hello world"
         credentials={credentials}
         excludeHosts={''}
         hosts="123.455.67.434"
         inUse={false}
         name="target"
-        reverseLookupOnly={NO_VALUE}
-        reverseLookupUnify={NO_VALUE}
+        reverseLookupOnly={false}
+        reverseLookupUnify={false}
         smbCredentialId="2345"
         onClose={handleClose}
-        onEsxiCredentialChange={handleChange}
-        onKrb5CredentialChange={handleChange}
         onNewCredentialsClick={handleCreate}
         onNewPortListClick={handleCreate}
         onPortListChange={handleChange}
         onSave={handleSave}
-        onSmbCredentialChange={handleChange}
-        onSnmpCredentialChange={handleChange}
-        onSshCredentialChange={handleChange}
-        onSshElevateCredentialChange={handleChange}
       />,
     );
 
@@ -245,23 +241,27 @@ describe('TargetDialog tests', () => {
     const allowSimultaneousIPsInputs = screen.getAllByName(
       'allowSimultaneousIPs',
     );
-    expect(allowSimultaneousIPsInputs[0]).toHaveAttribute('value', '1');
     expect(allowSimultaneousIPsInputs[0]).not.toBeChecked();
-    expect(allowSimultaneousIPsInputs[1]).toHaveAttribute('value', '0');
     expect(allowSimultaneousIPsInputs[1]).toBeChecked();
 
     expect(screen.getDialogContent()).not.toHaveTextContent(
       'Elevate privileges',
     ); // elevate privileges should not be rendered without valid sshCredentialId
 
-    const selects = screen.queryAllSelectElements();
-    expect(selects.length).toEqual(6); // Should have 6 selects (Kerberos is disabled by default)
-    expect(selects[0]).toHaveValue(DEFAULT_PORT_LIST_NAME); // alive test select
-    expect(selects[1]).toHaveValue(ALIVE_TESTS_DEFAULT); // alive test select
-    expect(selects[2]).toHaveValue(UNSET_LABEL); // ssh credential select
-    expect(selects[3]).toHaveValue('username+password'); // elevate privilege select
-    expect(selects[4]).toHaveValue(UNSET_LABEL); // smb credential select
-    expect(selects[5]).toHaveValue(UNSET_LABEL); // esxi credential select
+    expect(screen.getByName('aliveTests')).toHaveValue('');
+
+    const aliveTestsRadios = screen.getAllByName('baseAliveTests');
+    expect(aliveTestsRadios[0]).toHaveAttribute('value', 'Scan Config Default');
+    expect(aliveTestsRadios[0]).toBeChecked();
+    expect(aliveTestsRadios[1]).toHaveAttribute('value', 'Consider Alive');
+    expect(aliveTestsRadios[1]).not.toBeChecked();
+    expect(aliveTestsRadios[2]).toHaveAttribute('value', 'custom');
+    expect(aliveTestsRadios[2]).not.toBeChecked();
+
+    expect(screen.getByName('portListId')).toHaveValue(DEFAULT_PORT_LIST_ID);
+    expect(screen.getByName('sshCredentialId')).toHaveValue(undefined);
+    expect(screen.getByName('smbCredentialId')).toHaveValue('2345');
+    expect(screen.getByName('esxiCredentialId')).toHaveValue(undefined);
 
     expect(screen.getByTitle('Create a new port list')).toBeInTheDocument();
     const createCredentialIcons = screen.getAllByTitle(
@@ -270,15 +270,11 @@ describe('TargetDialog tests', () => {
     expect(createCredentialIcons.length).toEqual(4); // Each icon has both a span and an svg icon. There should be 4 total (Kerberos is disabled by default)
 
     const reverseLookupOnlyInputs = screen.getAllByName('reverseLookupOnly');
-    expect(reverseLookupOnlyInputs[0]).toHaveAttribute('value', '1');
     expect(reverseLookupOnlyInputs[0]).not.toBeChecked();
-    expect(reverseLookupOnlyInputs[1]).toHaveAttribute('value', '0');
     expect(reverseLookupOnlyInputs[1]).toBeChecked();
 
     const reverseLookupUnifyInputs = screen.getAllByName('reverseLookupUnify');
-    expect(reverseLookupUnifyInputs[0]).toHaveAttribute('value', '1');
     expect(reverseLookupUnifyInputs[0]).not.toBeChecked();
-    expect(reverseLookupUnifyInputs[1]).toHaveAttribute('value', '0');
     expect(reverseLookupUnifyInputs[1]).toBeChecked();
   });
 
@@ -292,28 +288,22 @@ describe('TargetDialog tests', () => {
 
     render(
       <TargetDialog
-        aliveTests={ALIVE_TESTS.SCAN_CONFIG_DEFAULT}
-        allowSimultaneousIPs={NO_VALUE}
+        aliveTests={[SCAN_CONFIG_DEFAULT]}
+        allowSimultaneousIPs={false}
         comment="hello world"
         credentials={credentials}
         excludeHosts=""
         hosts="123.455.67.434"
         inUse={false}
         name="target"
-        reverseLookupOnly={NO_VALUE}
-        reverseLookupUnify={YES_VALUE}
+        reverseLookupOnly={false}
+        reverseLookupUnify={true}
         smbCredentialId="2345"
         onClose={handleClose}
-        onEsxiCredentialChange={handleChange}
-        onKrb5CredentialChange={handleChange}
         onNewCredentialsClick={handleCreate}
         onNewPortListClick={handleCreate}
         onPortListChange={handleChange}
         onSave={handleSave}
-        onSmbCredentialChange={handleChange}
-        onSnmpCredentialChange={handleChange}
-        onSshCredentialChange={handleChange}
-        onSshElevateCredentialChange={handleChange}
       />,
     );
 
@@ -325,9 +315,7 @@ describe('TargetDialog tests', () => {
     const simultaneousIPInput = screen.getAllByName('allowSimultaneousIPs');
     expect(simultaneousIPInput.length).toBe(2);
     expect(simultaneousIPInput[0]).not.toBeChecked();
-    expect(simultaneousIPInput[0]).toHaveAttribute('value', '1');
     expect(simultaneousIPInput[1]).toBeChecked();
-    expect(simultaneousIPInput[1]).toHaveAttribute('value', '0');
 
     fireEvent.click(simultaneousIPInput[0]); // radio button check yes
 
@@ -335,24 +323,25 @@ describe('TargetDialog tests', () => {
     fireEvent.click(saveButton);
 
     expect(handleSave).toHaveBeenCalledWith({
-      aliveTests: ALIVE_TESTS.SCAN_CONFIG_DEFAULT,
-      allowSimultaneousIPs: YES_VALUE,
+      id: undefined,
+      aliveTests: [SCAN_CONFIG_DEFAULT],
+      allowSimultaneousIPs: true,
       comment: 'hello world',
-      esxiCredentialId: UNSET_VALUE,
+      esxiCredentialId: undefined,
       excludeHosts: '',
       hosts: '123.455.67.434',
       hostsCount: undefined,
       inUse: false,
       name: 'ross',
       port: 22,
-      portListId: 'c7e03b6c-3bbe-11e1-a057-406186ea4fc5',
-      reverseLookupOnly: 0,
-      reverseLookupUnify: YES_VALUE,
+      portListId: DEFAULT_PORT_LIST_ID,
+      reverseLookupOnly: false,
+      reverseLookupUnify: true,
       smbCredentialId: '2345',
-      snmpCredentialId: UNSET_VALUE,
-      sshCredentialId: UNSET_VALUE,
-      sshElevateCredentialId: UNSET_VALUE,
-      krb5CredentialId: UNSET_VALUE,
+      snmpCredentialId: undefined,
+      sshCredentialId: undefined,
+      sshElevateCredentialId: undefined,
+      krb5CredentialId: undefined,
       targetExcludeSource: 'manual',
       targetSource: 'manual',
     });
@@ -367,36 +356,30 @@ describe('TargetDialog tests', () => {
     const {render} = rendererWith({gmp, capabilities: true});
     render(
       <TargetDialog
-        aliveTests={ALIVE_TESTS.SCAN_CONFIG_DEFAULT}
-        allowSimultaneousIPs={NO_VALUE}
+        aliveTests={[SCAN_CONFIG_DEFAULT]}
+        allowSimultaneousIPs={false}
         comment="hello world"
         credentials={credentials}
         excludeHosts=""
         hosts="123.455.67.434"
         inUse={false}
         name="target"
-        reverseLookupOnly={NO_VALUE}
-        reverseLookupUnify={NO_VALUE}
+        reverseLookupOnly={false}
+        reverseLookupUnify={false}
         smbCredentialId="2345"
         sshCredentialId="2345"
         onClose={handleClose}
-        onEsxiCredentialChange={handleChange}
-        onKrb5CredentialChange={handleChange}
         onNewCredentialsClick={handleCreate}
         onNewPortListClick={handleCreate}
         onPortListChange={handleChange}
         onSave={handleSave}
-        onSmbCredentialChange={handleChange}
-        onSnmpCredentialChange={handleChange}
-        onSshCredentialChange={handleChange}
-        onSshElevateCredentialChange={handleChange}
       />,
     );
 
     expect(screen.getDialogContent()).toHaveTextContent('Elevate privileges');
 
     const selects = screen.queryAllSelectElements();
-    expect(selects.length).toEqual(7); // Should have 7 selects (Kerberos is disabled by default)
+    expect(selects.length).toEqual(6); // Should have 6 selects (Kerberos is disabled by default)
 
     const createCredentialIcons = screen.getAllByTitle(
       'Create a new credential',
@@ -413,42 +396,34 @@ describe('TargetDialog tests', () => {
     const {render} = rendererWith({gmp, capabilities: true});
     render(
       <TargetDialog
-        aliveTests={ALIVE_TESTS.SCAN_CONFIG_DEFAULT}
-        allowSimultaneousIPs={NO_VALUE}
+        aliveTests={[SCAN_CONFIG_DEFAULT]}
+        allowSimultaneousIPs={false}
         comment="hello world"
         credentials={credentials}
         excludeHosts=""
         hosts="123.455.67.434"
         inUse={false}
         name="target"
-        reverseLookupOnly={NO_VALUE}
-        reverseLookupUnify={NO_VALUE}
+        reverseLookupOnly={false}
+        reverseLookupUnify={false}
         smbCredentialId="5463"
         sshCredentialId="2345"
         onClose={handleClose}
-        onEsxiCredentialChange={handleChange}
-        onKrb5CredentialChange={handleChange}
         onNewCredentialsClick={handleCreate}
         onNewPortListClick={handleCreate}
         onPortListChange={handleChange}
         onSave={handleSave}
-        onSmbCredentialChange={handleChange}
-        onSnmpCredentialChange={handleChange}
-        onSshCredentialChange={handleChange}
-        onSshElevateCredentialChange={handleChange}
       />,
     );
 
     expect(screen.getDialogContent()).toHaveTextContent('Elevate privileges');
 
     const selects = screen.queryAllSelectElements();
-    expect(selects.length).toEqual(7); // Should have 7 selects (Kerberos is disabled by default)
+    expect(selects.length).toEqual(6); // Should have 6 selects (Kerberos is disabled by default)
 
-    const selectItems = await getSelectItemElementsForSelect(selects[3]);
-    expect(selectItems.length).toBe(2); // "original" ssh option removed
-
-    expect(selectItems[0]).toHaveTextContent('--'); // null option
-    expect(selectItems[1]).toHaveTextContent('up2');
+    const selectItems = await getSelectItemElementsForSelect(selects[2]);
+    expect(selectItems.length).toBe(1);
+    expect(selectItems[0]).toHaveTextContent('up2');
   });
 
   test.each([
@@ -494,8 +469,8 @@ describe('TargetDialog tests', () => {
 
       render(
         <TargetDialog
-          aliveTests={ALIVE_TESTS.SCAN_CONFIG_DEFAULT}
-          allowSimultaneousIPs={NO_VALUE}
+          aliveTests={[SCAN_CONFIG_DEFAULT]}
+          allowSimultaneousIPs={false}
           comment="hello world"
           credentials={credentials}
           excludeHosts=""
@@ -503,20 +478,14 @@ describe('TargetDialog tests', () => {
           inUse={false}
           krb5CredentialId="2345"
           name="target"
-          reverseLookupOnly={NO_VALUE}
-          reverseLookupUnify={NO_VALUE}
+          reverseLookupOnly={false}
+          reverseLookupUnify={false}
           smbCredentialId="5463"
           onClose={handleClose}
-          onEsxiCredentialChange={handleChange}
-          onKrb5CredentialChange={handleChange}
           onNewCredentialsClick={handleCreate}
           onNewPortListClick={handleCreate}
           onPortListChange={handleChange}
           onSave={handleSave}
-          onSmbCredentialChange={handleChange}
-          onSnmpCredentialChange={handleChange}
-          onSshCredentialChange={handleChange}
-          onSshElevateCredentialChange={handleChange}
         />,
       );
 
@@ -545,43 +514,36 @@ describe('TargetDialog tests', () => {
 
     render(
       <TargetDialog
-        aliveTests={ALIVE_TESTS.SCAN_CONFIG_DEFAULT}
-        allowSimultaneousIPs={NO_VALUE}
+        aliveTests={[SCAN_CONFIG_DEFAULT]}
+        allowSimultaneousIPs={false}
         comment="hello world"
         credentials={credentials}
         excludeHosts=""
         hosts="123.455.67.434"
         inUse={false}
         name="target"
-        reverseLookupOnly={NO_VALUE}
-        reverseLookupUnify={NO_VALUE}
+        reverseLookupOnly={false}
+        reverseLookupUnify={false}
         sshCredentialId="2345"
         sshElevateCredentialId="5463"
         onClose={handleClose}
-        onEsxiCredentialChange={handleChange}
-        onKrb5CredentialChange={handleChange}
         onNewCredentialsClick={handleCreate}
         onNewPortListClick={handleCreate}
         onPortListChange={handleChange}
         onSave={handleSave}
-        onSmbCredentialChange={handleChange}
-        onSnmpCredentialChange={handleChange}
-        onSshCredentialChange={handleChange}
-        onSshElevateCredentialChange={handleChange}
       />,
     );
 
     expect(screen.getDialogContent()).toHaveTextContent('Elevate privileges');
 
     const selects = screen.queryAllSelectElements();
-    expect(selects.length).toEqual(7); // Should have 7 selects (Kerberos is disabled by default)
+    expect(selects.length).toEqual(6); // Should have 6 selects (Kerberos is disabled by default)
 
-    const selectItems = await getSelectItemElementsForSelect(selects[2]);
-    expect(selectItems.length).toBe(3); // ssh elevate option removed
+    const selectItems = await getSelectItemElementsForSelect(selects[1]);
+    expect(selectItems.length).toBe(2); // ssh elevate option removed
 
-    expect(selectItems[0]).toHaveTextContent(UNSET_LABEL); // null option
-    expect(selectItems[1]).toHaveTextContent('username+password');
-    expect(selectItems[2]).toHaveTextContent('ssh_key');
+    expect(selectItems[0]).toHaveTextContent('username+password');
+    expect(selectItems[1]).toHaveTextContent('ssh_key');
   });
 
   test('should disable editing certain fields if target is in use', () => {
@@ -594,29 +556,23 @@ describe('TargetDialog tests', () => {
 
     render(
       <TargetDialog
-        aliveTests={ALIVE_TESTS.SCAN_CONFIG_DEFAULT}
-        allowSimultaneousIPs={NO_VALUE}
+        aliveTests={[SCAN_CONFIG_DEFAULT]}
+        allowSimultaneousIPs={false}
         comment="hello world"
         credentials={credentials}
         excludeHosts=""
         hosts="123.455.67.434"
         inUse={true}
         name="target"
-        reverseLookupOnly={NO_VALUE}
-        reverseLookupUnify={NO_VALUE}
+        reverseLookupOnly={false}
+        reverseLookupUnify={false}
         sshCredentialId="2345"
         sshElevateCredentialId="5463"
         onClose={handleClose}
-        onEsxiCredentialChange={handleChange}
-        onKrb5CredentialChange={handleChange}
         onNewCredentialsClick={handleCreate}
         onNewPortListClick={handleCreate}
         onPortListChange={handleChange}
         onSave={handleSave}
-        onSmbCredentialChange={handleChange}
-        onSnmpCredentialChange={handleChange}
-        onSshCredentialChange={handleChange}
-        onSshElevateCredentialChange={handleChange}
       />,
     );
 
@@ -626,25 +582,25 @@ describe('TargetDialog tests', () => {
     expect(newIcons.length).toBe(0); // no new credential can be created
 
     const selects = screen.queryAllSelectElements();
-    expect(selects.length).toEqual(7); // Should have 7 selects (Kerberos is disabled by default)
+    expect(selects.length).toEqual(6); // Should have 6 selects (Kerberos is disabled by default)
 
-    expect(selects[0]).toHaveValue('OpenVAS Default');
+    expect(selects[0]).toHaveValue(DEFAULT_PORT_LIST_NAME);
     expect(selects[0]).toBeDisabled();
 
-    expect(selects[1]).toHaveValue(ALIVE_TESTS.SCAN_CONFIG_DEFAULT);
-    expect(selects[2]).toHaveValue('username+password');
+    expect(selects[1]).toHaveValue('username+password');
+    expect(selects[1]).toBeDisabled();
+
+    expect(selects[2]).toHaveValue('up2');
     expect(selects[2]).toBeDisabled();
 
-    expect(selects[3]).toHaveValue('up2');
+    expect(selects[3]).toHaveValue('');
     expect(selects[3]).toBeDisabled();
-    expect(selects[4]).toHaveValue('--');
+
+    expect(selects[4]).toHaveValue('');
     expect(selects[4]).toBeDisabled();
 
-    expect(selects[5]).toHaveValue('--');
+    expect(selects[5]).toHaveValue('');
     expect(selects[5]).toBeDisabled();
-
-    expect(selects[6]).toHaveValue('--');
-    expect(selects[6]).toBeDisabled();
   });
 
   test('should allow to close the dialog', () => {
@@ -659,16 +615,10 @@ describe('TargetDialog tests', () => {
       <TargetDialog
         credentials={credentials}
         onClose={handleClose}
-        onEsxiCredentialChange={handleChange}
-        onKrb5CredentialChange={handleChange}
         onNewCredentialsClick={handleCreate}
         onNewPortListClick={handleCreate}
         onPortListChange={handleChange}
         onSave={handleSave}
-        onSmbCredentialChange={handleChange}
-        onSnmpCredentialChange={handleChange}
-        onSshCredentialChange={handleChange}
-        onSshElevateCredentialChange={handleChange}
       />,
     );
 
@@ -705,27 +655,132 @@ describe('TargetDialog tests', () => {
     const saveButton = screen.getDialogSaveButton();
     fireEvent.click(saveButton);
     expect(handleSave).toHaveBeenCalledWith({
-      aliveTests: ALIVE_TESTS.SCAN_CONFIG_DEFAULT,
-      allowSimultaneousIPs: YES_VALUE,
+      aliveTests: [SCAN_CONFIG_DEFAULT],
+      allowSimultaneousIPs: true,
       comment: '',
-      esxiCredentialId: UNSET_VALUE,
+      esxiCredentialId: undefined,
       excludeHosts: '',
       hosts: '',
       hostsCount: 10,
       hostsFilter,
+      id: undefined,
       inUse: false,
       name: 'Unnamed',
       port: 22,
-      portListId: 'c7e03b6c-3bbe-11e1-a057-406186ea4fc5',
-      reverseLookupOnly: 0,
-      reverseLookupUnify: 0,
-      smbCredentialId: UNSET_VALUE,
-      snmpCredentialId: UNSET_VALUE,
-      sshCredentialId: UNSET_VALUE,
-      sshElevateCredentialId: UNSET_VALUE,
-      krb5CredentialId: UNSET_VALUE,
+      portListId: DEFAULT_PORT_LIST_ID,
+      reverseLookupOnly: false,
+      reverseLookupUnify: false,
+      smbCredentialId: undefined,
+      snmpCredentialId: undefined,
+      sshCredentialId: undefined,
+      sshElevateCredentialId: undefined,
+      krb5CredentialId: undefined,
       targetExcludeSource: 'manual',
       targetSource: 'asset_hosts',
     });
   });
+
+  describe('New Credential Icons', () => {
+    test.each([
+      [
+        'new-icon-esxi',
+        'esxiCredentialId',
+        'Create new ESXi credential',
+        ESXI_CREDENTIAL_TYPES,
+      ],
+      [
+        'new-icon-ssh',
+        'sshCredentialId',
+        'Create new SSH credential',
+        SSH_CREDENTIAL_TYPES,
+      ],
+
+      [
+        'new-icon-smb',
+        'smbCredentialId',
+        'Create new SMB credential',
+        SMB_CREDENTIAL_TYPES,
+      ],
+      [
+        'new-icon-snmp',
+        'snmpCredentialId',
+        'Create new SNMP credential',
+        SNMP_CREDENTIAL_TYPES,
+      ],
+    ])(
+      'should render NewIcon for %s when conditions are met',
+      (testId, idField, title, types) => {
+        const handleCreate = testing.fn();
+
+        const {render} = rendererWith({gmp, capabilities: true});
+
+        render(
+          <TargetDialog
+            credentials={credentials}
+            inUse={false}
+            onNewCredentialsClick={handleCreate}
+          />,
+        );
+
+        const newIcon = screen.getByTestId(testId);
+        expect(newIcon).toBeInTheDocument();
+        fireEvent.click(newIcon);
+        expect(handleCreate).toHaveBeenCalledWith({
+          idField,
+          title,
+          types,
+        });
+      },
+    );
+  });
+
+  test('should allow to render consider alive alive tests', () => {
+    const handleClose = testing.fn();
+    const handleSave = testing.fn();
+
+    const {render} = rendererWith({gmp, capabilities: true});
+
+    render(
+      <TargetDialog
+        aliveTests={[CONSIDER_ALIVE]}
+        onClose={handleClose}
+        onSave={handleSave}
+      />,
+    );
+
+    expect(screen.getByName('aliveTests')).toHaveValue('');
+
+    const aliveTestsRadios = screen.getAllByName('baseAliveTests');
+    expect(aliveTestsRadios[0]).toHaveAttribute('value', 'Scan Config Default');
+    expect(aliveTestsRadios[0]).not.toBeChecked();
+    expect(aliveTestsRadios[1]).toHaveAttribute('value', 'Consider Alive');
+    expect(aliveTestsRadios[1]).toBeChecked();
+    expect(aliveTestsRadios[2]).toHaveAttribute('value', 'custom');
+    expect(aliveTestsRadios[2]).not.toBeChecked();
+  });
+
+  test('should allow to render custom alive tests', () => {
+    const handleClose = testing.fn();
+    const handleSave = testing.fn();
+
+    const {render} = rendererWith({gmp, capabilities: true});
+
+    render(
+      <TargetDialog
+        aliveTests={[ICMP_PING, ARP_PING]}
+        onClose={handleClose}
+        onSave={handleSave}
+      />,
+    );
+
+    expect(screen.getByName('aliveTests')).toHaveValue('ICMP Ping,ARP Ping');
+
+    const aliveTestsRadios = screen.getAllByName('baseAliveTests');
+    expect(aliveTestsRadios[0]).toHaveAttribute('value', 'Scan Config Default');
+    expect(aliveTestsRadios[0]).not.toBeChecked();
+    expect(aliveTestsRadios[1]).toHaveAttribute('value', 'Consider Alive');
+    expect(aliveTestsRadios[1]).not.toBeChecked();
+    expect(aliveTestsRadios[2]).toHaveAttribute('value', 'custom');
+    expect(aliveTestsRadios[2]).toBeChecked();
+  });
 });
