@@ -662,6 +662,7 @@ describe('UserSettingsPage', () => {
       render(<UserSettingsPage />);
       expect(screen.queryByText('Filters')).not.toBeInTheDocument();
     });
+
     test('displays filter settings headers and links in the Filters tab', async () => {
       const gmp = createGmpMock();
 
@@ -673,7 +674,11 @@ describe('UserSettingsPage', () => {
       });
 
       const entityTypeToDisplayName = {
+        agentgroup: 'Agent Groups',
+        agentinstaller: 'Agent Installers',
+        agent: 'Agents',
         alert: 'Alerts',
+        audit: 'Audits',
         auditreport: 'Audit Reports',
         scanconfig: 'Configs',
         credential: 'Credentials',
@@ -684,8 +689,10 @@ describe('UserSettingsPage', () => {
         operatingsystem: 'Operating Systems',
         override: 'Overrides',
         permission: 'Permissions',
+        policy: 'Policies',
         portlist: 'Port Lists',
         report: 'Reports',
+        reportconfig: 'Report Configs',
         reportformat: 'Report Formats',
         result: 'Results',
         role: 'Roles',
