@@ -1,20 +1,8 @@
-/* Copyright (C) 2019-2022 Greenbone AG
+/* SPDX-FileCopyrightText: 2024 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Affero General Public License
- * as published by the Free Software Foundation, either version 3
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
+
 import {isDefined} from 'gmp/utils/identity';
 
 export const simplifiedReportIdentifier = (reportId, filter) => {
@@ -90,5 +78,11 @@ class DeltaReportSelector {
 export const reportSelector = rootState =>
   new ReportSelector(rootState.entities.report);
 
+export const auditReportSelector = rootState =>
+  new ReportSelector(rootState.entities.auditreport);
+
 export const deltaReportSelector = rootState =>
   new DeltaReportSelector(rootState.entities.deltaReport);
+
+export const deltaAuditReportSelector = rootState =>
+  new DeltaReportSelector(rootState.entities.deltaAuditReport);
